use url::Url;
use std::sync::Mutex;

lazy_static! {
    static ref HISTORY: Mutex<Vec<Url>> = Mutex::new(vec![]);
}

pub fn init() {
    let mut history = HISTORY.lock().unwrap();
    let start_page = Url::parse("gemini://start_page").unwrap();
    history.push(start_page);
}

pub fn content() -> Vec<Url> {
    HISTORY.lock().unwrap().to_vec()
}

pub fn append(url: &str) {
    let url = Url::parse(url).unwrap();
    HISTORY.lock().unwrap().push(url)
}

pub fn get_current_host() -> Option<String> {
    let history = HISTORY.lock().unwrap();
    match history.last() {
        Some(current_url) => {
            match current_url.host_str() {
                Some(host) => Some(String::from(host)),
                None => None
            }
        }
        None => None
    }
}
